:tocdepth: 1

.. role:: small
.. role:: smaller

Release Notes
=============

Version 0.0.3 :small:`April 8, 2021`
-------------------------------------

This version includes:

    - Consensus tree builder with CLI command.
    - Some new utility functions such as converting a tree fo conflict-free matrix.
    - Bifiltering ILP code for selecting the maximal informed submatrix.


Version 0.0.2 :small:`March 29, 2021`
-------------------------------------

Second beta release of Trisicell. This version includes:

    - Solvers including (SCITE, PhISCS and etc).
    - Preprocessing of the readcount matrices.
    - Partition function estimation.
    - Mutation calling commands for genotyping single-cell RNA data.
    - Set of genotype noisy/solution datasets.
    - Functions for comparing two clonal trees.
    - Functions for plotting clonal/dendrogram trees.


Version 0.0.1 :small:`March 25, 2021`
-------------------------------------

First beta release of Trisicell.
